Object.defineProperty(exports, "__esModule", {
  value: true
});
exports['default'] = resolveWithRTL;

var _arrayFlatten = require('array-flatten');

var _util = require('aphrodite/lib/util');

var _separateStyles2 = require('./separateStyles');

var _separateStyles3 = _interopRequireDefault(_separateStyles2);

var _generateDirectionalStyles = require('./generateDirectionalStyles');

var _generateDirectionalStyles2 = _interopRequireDefault(_generateDirectionalStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } } /* eslint-disable no-underscore-dangle, no-param-reassign */


function setStyleDefinitionWithRTL(stylesObj) {
  // Since we are mutating the StyleSheet object directly, we want to cache the withRTL/noRTL
  // results and then set the _definition key to point to the appropriate version when necessary.
  if (!stylesObj.withRTL || !stylesObj.noRTL) {
    // The _definition key is an implementation detail of aphrodite. If aphrodite
    // changes it in the future, this code will need to be updated.
    var definition = stylesObj._definition;
    stylesObj.noRTL = definition;

    var directionalStyles = (0, _generateDirectionalStyles2['default'])(definition);
    stylesObj.withRTL = directionalStyles || definition;
  }
  stylesObj._definition = stylesObj.withRTL;
  return stylesObj;
}

// Styles is an array of properties returned by `create()`, a POJO, or an
// array thereof. POJOs are treated as inline styles. The default resolve
// method makes an effort to flip CSS styles for an RTL context.
// This function returns an object to be spread onto an element.
function resolveWithRTL(css, styles) {
  var flattenedStyles = (0, _arrayFlatten.from)(styles);

  var _separateStyles = (0, _separateStyles3['default'])(flattenedStyles, setStyleDefinitionWithRTL),
      aphroditeStyles = _separateStyles.aphroditeStyles,
      hasInlineStyles = _separateStyles.hasInlineStyles,
      inlineStyles = _separateStyles.inlineStyles;

  var result = {};
  if (hasInlineStyles) {
    var inlineRTLStyles = (0, _generateDirectionalStyles2['default'])(inlineStyles);

    if (inlineRTLStyles) {
      // Because we know nothing about the current directional context, there
      // is no way to determine whether or not the inline styles should be
      // flipped. As a result, if there are inline styles to be flipped, we
      // do so by converting them to classnames and providing styles in both
      // an RTL and an LTR context.
      // This may not work for all situations! For instance, when using inline
      // styles to animate a component with react-motion or animated.js,
      // converting to classes is likely to be way too slow. For those and
      // other edge-cases, consumers should rely on the resolveNoRTL method
      // instead.
      aphroditeStyles.push({
        _name: 'inlineStyles_' + String((0, _util.hashObject)(inlineRTLStyles)),
        _definition: inlineRTLStyles
      });
    } else {
      result.style = inlineStyles;
    }
  }

  if (aphroditeStyles.length > 0) {
    result.className = css.apply(undefined, _toConsumableArray(aphroditeStyles));
  }

  return result;
}